@@ -317,8 +317,8 @@ sub load_robots {
         } else {
             $param->{'config_hash'}{'robots'}{$robot} = $robot_conf;
         }
-        _check_double_url_usage(
-            {'config_hash' => $param->{'config_hash'}{'robots'}{$robot}});
+        #_check_double_url_usage(
+        #    {'config_hash' => $param->{'config_hash'}{'robots'}{$robot}});
     }
     return undef if ($exiting);
     return 1;
@@ -2016,14 +2016,6 @@ sub _infer_server_specific_parameter_values {
         };
     }
 
-    ## Default SOAP URL corresponds to default robot
-    if ($param->{'config_hash'}{'soap_url'}) {
-        my $url = $param->{'config_hash'}{'soap_url'};
-        $url =~ s/^http(s)?:\/\/(.+)$/$2/;
-        $param->{'config_hash'}{'robot_by_soap_url'}{$url} =
-            $param->{'config_hash'}{'domain'};
-    }
-
     return 1;
 }
 
@@ -2105,13 +2097,6 @@ sub _infer_robot_parameter_values {
         $param->{'config_hash'}{'blacklist'}{$action} = 1;
     }
 
-    ## Create a hash to deduce robot from SOAP url
-    if ($param->{'config_hash'}{'soap_url'}) {
-        my $url = $param->{'config_hash'}{'soap_url'};
-        $url =~ s/^http(s)?:\/\/(.+)$/$2/;
-        $Conf{'robot_by_soap_url'}{$url} =
-            $param->{'config_hash'}{'robot_name'};
-    }
     # Hack because multi valued parameters are not available for Sympa 6.1.
     if (defined $param->{'config_hash'}{'automatic_list_families'}) {
         my @families = split ';',
@@ -2377,36 +2362,8 @@ sub _set_listmasters_entry {
     return $number_of_valid_email;
 }
 
-sub _check_double_url_usage {
-    my $param = shift;
-    my ($host, $path);
-    if (Sympa::Tools::Data::smart_eq(
-            $param->{'config_hash'}{'http_host'},
-            qr/^([^\/]+)(\/.*)$/
-        )
-        ) {
-        $param->{'config_hash'}{'http_host'} =~ qr/^([^\/]+)(\/.*)$/;
-        ($host, $path) = ($1, $2);
-    } else {
-        ($host, $path) = ($param->{'config_hash'}{'http_host'}, '/');
-    }
-
-    ## Warn listmaster if another virtual host is defined with the same host
-    ## +path
-    if (defined $Conf{'robot_by_http_host'}{$host}{$path}) {
-        $log->syslog(
-            'err',
-            'Two virtual hosts (%s and %s) are mapped via a single URL "%s%s"',
-            $Conf{'robot_by_http_host'}{$host}{$path},
-            $param->{'config_hash'}{'robot_name'},
-            $host,
-            $path
-        );
-    }
-
-    $Conf{'robot_by_http_host'}{$host}{$path} =
-        $param->{'config_hash'}{'robot_name'};
-}
+# No longer used.
+#sub _check_double_url_usage;
 
 sub _parse_custom_robot_parameters {
     my $param           = shift;
