@@ -58,7 +58,6 @@ use Sympa::Robot;
 use Sympa::Scenario;
 use Sympa::Template;
 use Sympa::Tools::File;
-use Sympa::User;
 
 my $language = Sympa::Language->instance;
 my $log      = Sympa::Log->instance;
@@ -1560,177 +1559,8 @@ sub check_topics {
     return undef;
 }
 
-# change a user email address for both his memberships and ownerships
-#
-# IN  : - current_email : current user email address
-#       - new_email     : new user email address
-#       - robot         : virtual robot
-#
-# OUT : - status(scalar)          : status of the subroutine
-#       - failed_for(arrayref)    : list of lists for which the change could
-#       not be done (because user was
-#                                   included or for authorization reasons)
-sub change_user_email {
-    my %in = @_;
-
-    my $robot_id = $in{'robot'};
-
-    my @failed_for;
-
-    unless ($in{'current_email'} and $in{'new_email'} and $in{'robot'}) {
-        die 'Missing incoming parameter';
-    }
-
-    ## Change email as list MEMBER
-    foreach my $list (
-        Sympa::List::get_which($in{'current_email'}, $robot_id, 'member')) {
-        my $l = $list->{'name'};
-
-        my $user_entry = $list->get_list_member($in{'current_email'});
-
-        if ($user_entry->{'included'} == 1) {
-            # Check the type of data sources.
-            # If only include_sympa_list of local mailing lists, then no
-            # problem.  Otherwise, notify list owner.
-            # We could also force a sync_include for local lists.
-            my $use_external_data_sources;
-            foreach my $datasource_id (split(/,/, $user_entry->{'id'})) {
-                my $datasource = $list->search_datasource($datasource_id);
-                if (   !defined $datasource
-                    or $datasource->{'type'} ne 'include_sympa_list'
-                    or (    $datasource->{'def'} =~ /\@(.+)$/
-                        and $1 ne $robot_id)
-                    ) {
-                    $use_external_data_sources = 1;
-                    last;
-                }
-            }
-            if ($use_external_data_sources) {
-                ## Notify list owner
-                $list->send_notify_to_owner(
-                    'failed_to_change_included_member',
-                    {   'current_email' => $in{'current_email'},
-                        'new_email'     => $in{'new_email'},
-                        'datasource' =>
-                            $list->get_datasource_name($user_entry->{'id'})
-                    }
-                );
-                push @failed_for, $list;
-                $log->syslog(
-                    'err',
-                    'Could not change member email for list %s because member is included',
-                    $l
-                );
-                next;
-            }
-        }
-
-        ## Check if user is already member of the list with his new address
-        ## then we just need to remove the old address
-        if ($list->is_list_member($in{'new_email'})) {
-            unless (
-                $list->delete_list_member('users' => [$in{'current_email'}]))
-            {
-                push @failed_for, $list;
-                $log->syslog('info', 'Could not remove email from list %s',
-                    $l);
-            }
-
-        } else {
-            unless (
-                $list->update_list_member(
-                    $in{'current_email'},
-                    email       => $in{'new_email'},
-                    update_date => time
-                )
-                ) {
-                push @failed_for, $list;
-                $log->syslog('err', 'Could not change email for list %s', $l);
-            }
-        }
-    }
-
-    ## Change email as list OWNER/MODERATOR
-    my %updated_lists;
-    foreach my $role ('owner', 'editor') {
-        foreach my $list (
-            Sympa::List::get_which($in{'current_email'}, $robot_id, $role)) {
-            # Check if admin is included via an external datasource
-            my ($admin_user) = @{
-                $list->get_admins($role,
-                    filter => [email => $in{'current_email'}])
-            };
-            if ($admin_user and $admin_user->{'included'}) {
-                # Notify listmaster
-                Sympa::send_notify_to_listmaster(
-                    $list,
-                    'failed_to_change_included_admin',
-                    {   'current_email' => $in{'current_email'},
-                        'new_email'     => $in{'new_email'},
-                        'datasource' =>
-                            $list->get_datasource_name($admin_user->{'id'})
-                    }
-                );
-                push @failed_for, $list;
-                $log->syslog(
-                    'err',
-                    'Could not change %s email for list %s because admin is included',
-                    $role,
-                    $list->{'name'}
-                );
-                next;
-            }
-
-            ## Go through owners/editors of the list
-            foreach my $admin (@{$list->{'admin'}{$role}}) {
-                next
-                    unless (
-                    lc($admin->{'email'}) eq lc($in{'current_email'}));
-
-                ## Update entry with new email address
-                $admin->{'email'} = $in{'new_email'};
-                $updated_lists{$list->{'name'}}++;
-            }
-
-            ## Update Db cache for the list
-            $list->sync_include_admin();
-            $list->save_config();
-        }
-    }
-    ## Notify listmasters that list owners/moderators email have changed
-    if (keys %updated_lists) {
-        Sympa::send_notify_to_listmaster(
-            $robot_id,
-            'listowner_email_changed',
-            {   'previous_email' => $in{'current_email'},
-                'new_email'      => $in{'new_email'},
-                'updated_lists'  => keys %updated_lists
-            }
-        );
-    }
-
-    ## Update User_table and remove existing entry first (to avoid duplicate
-    ## entries)
-    my $oldu = Sympa::User->new($in{'new_email'});
-    $oldu->expire if $oldu;
-    my $u = Sympa::User->new($in{'current_email'});
-    unless ($u and $u->moveto($in{'new_email'})) {
-        $log->syslog('err', 'Update failed');
-        return undef;
-    }
-
-    ## Update netidmap_table
-    unless (
-        Sympa::Robot::update_email_netidmap_db(
-            $in{'robot'}, $in{'current_email'}, $in{'new_email'}
-        )
-        ) {
-        $log->syslog('err', 'Update failed');
-        return undef;
-    }
-
-    return (1, \@failed_for);
-}
+# Moved to Sympa::Request::Handler::move_user::_twist().
+#sub change_user_email;
 
 =pod 
 
