@@ -8,6 +8,9 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+# directory of this distribution and at
+# <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1203,7 +1206,7 @@ RFC 5646 I<Tags for Identifying Languages>.
 L<http://tools.ietf.org/html/rfc5646>.
 
 I<Translating Sympa>.
-L<http://www.sympa.org/translating_sympa>.
+L<https://translate.sympa.org/pages/help>.
 
 =head1 HISTORY
 
