@@ -8,6 +8,9 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+# directory of this distribution and at
+# <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,7 +42,7 @@ use Sympa::Request;
 use Sympa::Robot;
 use Sympa::Scenario;
 use Sympa::Session;
-use Sympa::Spool::Auth;
+use Sympa::Spindle::ProcessRequest;
 use Sympa::Template;
 use Sympa::Tools::Password;
 use Sympa::Tools::Text;
@@ -512,7 +515,8 @@ sub info {
         unless (defined $action);
 
     if ($action =~ /reject/i) {
-        my $reason_string = get_reason_string($result->{'reason'}, $robot);
+        my $reason_string = get_reason_string(
+            [{action => 'info'}, 'auth', $result->{'reason'}], $robot);
         $log->syslog('info', 'Info %s from %s refused (not allowed)',
             $listname, $sender);
         die SOAP::Fault->faultcode('Server')->faultstring('Not allowed')
@@ -822,124 +826,42 @@ sub add {
             ->faultdetail("Undefined list");
     }
 
-    # check authorization
-
-    my $result = Sympa::Scenario::request_action(
-        $list, 'add', 'md5',
-        {   'sender'                  => $sender,
-            'email'                   => $email,
-            'remote_host'             => $ENV{'REMOTE_HOST'},
-            'remote_addr'             => $ENV{'REMOTE_ADDR'},
-            'remote_application_name' => $ENV{'remote_application_name'}
+    my $spindle = Sympa::Spindle::ProcessRequest->new(
+        context          => $list,
+        action           => 'add',
+        sender           => $sender,
+        email            => $email,
+        gecos            => $gecos,
+        quiet            => $quiet,
+        md5_check        => 1,
+        scenario_contest => {
+            sender                  => $sender,
+            email                   => $email,
+            remote_host             => $ENV{'REMOTE_HOST'},
+            remote_addr             => $ENV{'REMOTE_ADDR'},
+            remote_application_name => $ENV{'remote_application_name'}
         }
     );
-
-    my $action;
-    my $reason;
-    if (ref($result) eq 'HASH') {
-        $action = $result->{'action'};
-        $reason = $result->{'reason'};
+    unless ($spindle and $spindle->spin) {
+        die SOAP::Fault->faultcode('Server')->faultstring('Internal error');
     }
 
-    unless (defined $action) {
-        $log->syslog('info', 'Add %s@%s %s from %s: scenario error',
-            $listname, $robot, $email, $sender);
-        die SOAP::Fault->faultcode('Server')->faultstring('scenario error')
-            ->faultdetail(
-            "sender $sender email $email remote $ENV{'remote_application_name'} "
-            );
-    }
-
-    unless ($action =~ /do_it/) {
-        my $reason_string = get_reason_string($reason, $robot);
-        $log->syslog('info', 'Add %s@%s %s from %s refused (not allowed)',
-            $listname, $robot, $email, $sender);
-        die SOAP::Fault->faultcode('Client')->faultstring('Not allowed')
-            ->faultdetail($reason_string);
-    }
-
-    if ($list->is_list_member($email)) {
-        $log->syslog('err',
-            'Add %s@%s %s from %s: Failed, user already member of the list',
-            $listname, $robot, $email, $sender);
-        my $error = "User already member of list $listname";
-        die SOAP::Fault->faultcode('Server')
-            ->faultstring('Unable to add user')->faultdetail($error);
-
-    } else {
-        # If a list is not 'open' and allow_subscribe_if_pending has been set
-        # to 'off' returns error report.
-        unless ($list->{'admin'}{'status'} eq 'open'
-            or Conf::get_robot_conf($robot, 'allow_subscribe_if_pending') eq
-            'on') {
-            my $error =
-                sprintf 'Service unavailable because list status is \'%s\'',
-                $list->{'admin'}{'status'};
-            $log->syslog('info', 'List %s not open', $list);
-            die SOAP::Fault::faultcode("Server")
-                ->faultstring('List not open')->faultdetail($error);
-        }
-
-        my $u;
-        my $defaults = $list->get_default_user_options();
-        my $u2       = Sympa::User->new($email);
-        %{$u} = %{$defaults};
-        $u->{'email'} = $email;
-        $u->{'gecos'} = $gecos || $u2->gecos;
-        $u->{'date'}  = $u->{'update_date'} = time;
-
-        # If Password validation is enabled check the submitted password
-        # against the site configured constraints
-        if ($u2->{'password'}) {
-            if (my $result =
-                Sympa::Tools::Password::password_validation($u->{'password'}))
-            {
-                $log->syslog('info', 'add %s@%s %s from %s : scenario error',
-                    $listname, $robot, $email, $sender);
-                die SOAP::Fault->faultcode('Server')
-                    ->faultstring('Weak password')
-                    ->faultdetail('Weak password: ' . $result);
-            }
-            $u->{'password'} = $u2->{'password'};
-        } else {
-            $u->{'password'} = Sympa::Tools::Password::tmp_passwd($email);
-        }
-
-        $u->{'lang'} = $u2->lang || $list->{'admin'}{'lang'};
-
-        $list->add_list_member($u);
-        if (defined $list->{'add_outcome'}{'errors'}) {
-            $log->syslog('info', 'Add %s@%s %s from %s: Unable to add user',
-                $listname, $robot, $email, $sender);
-            my $error = sprintf "Unable to add user %s in list %s: %s",
-                $email, $listname,
-                $list->{'add_outcome'}{'errors'}{'error_message'};
+    foreach my $report (@{$spindle->{stash} || []}) {
+        my $reason_string = get_reason_string($report, $robot);
+        if ($report->[1] eq 'auth') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
+                ->faultdetail($reason_string);
+        } elsif ($report->[1] eq 'intern') {
             die SOAP::Fault->faultcode('Server')
-                ->faultstring('Unable to add user')->faultdetail($error);
+                ->faultstring('Internal error');
+        } elsif ($report->[1] eq 'notice') {
+            return SOAP::Data->name('result')->type('boolean')->value(1);
+        } elsif ($report->[1] eq 'user') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Undef')
+                ->faultdetail($reason_string);
         }
     }
-
-    ## Now send the welcome file to the user if it exists and notification is
-    ## supposed to be sent.
-    unless ($quiet || $action =~ /quiet/i) {
-        unless ($list->send_probe_to_user('welcome', $email)) {
-            $log->syslog('notice', 'Unable to send "welcome" probe to %s',
-                $email);
-        }
-    }
-
-    $log->syslog('info', 'ADD %s %s from %s accepted (%d subscribers)',
-        $list->{'name'}, $email, $sender, $list->get_total());
-    if ($action =~ /notify/i) {
-        $list->send_notify_to_owner(
-            'notice',
-            {   'who'     => $email,
-                'gecos'   => $gecos,
-                'command' => 'add',
-                'by'      => $sender
-            }
-        );
-    }
+    return SOAP::Data->name('result')->type('boolean')->value(1);
 }
 
 sub del {
@@ -987,108 +909,41 @@ sub del {
             ->faultdetail("Undefined list");
     }
 
-    # check authorization
-
-    my $result = Sympa::Scenario::request_action(
-        $list, 'del', 'md5',
-        {   'sender'                  => $sender,
-            'email'                   => $email,
-            'remote_host'             => $ENV{'REMOTE_HOST'},
-            'remote_addr'             => $ENV{'REMOTE_ADDR'},
-            'remote_application_name' => $ENV{'remote_application_name'}
+    my $spindle = Sympa::Spindle::ProcessRequest->new(
+        context          => $list,
+        action           => 'del',
+        sender           => $sender,
+        email            => $email,
+        quiet            => $quiet,
+        md5_check        => 1,
+        scenario_contest => {
+            sender                  => $sender,
+            email                   => $email,
+            remote_host             => $ENV{'REMOTE_HOST'},
+            remote_addr             => $ENV{'REMOTE_ADDR'},
+            remote_application_name => $ENV{'remote_application_name'}
         }
     );
-
-    my $action;
-    my $reason;
-    if (ref($result) eq 'HASH') {
-        $action = $result->{'action'};
-        $reason = $result->{'reason'};
+    unless ($spindle and $spindle->spin) {
+        die SOAP::Fault->faultcode('Server')->faultstring('Internal error');
     }
 
-    unless (defined $action) {
-        $log->syslog('info', 'Del %s@%s %s from %s: scenario error',
-            $listname, $robot, $email, $sender);
-        die SOAP::Fault->faultcode('Server')->faultstring('scenario error')
-            ->faultdetail(
-            "sender $sender email $email remote $ENV{'remote_application_name'} "
-            );
-    }
-
-    unless ($action =~ /do_it/) {
-        my $reason_string = get_reason_string($reason, $robot);
-        $log->syslog('info',
-            'Del %s@%s %s from %s by %srefused (not allowed)',
-            $listname, $robot, $email, $sender,
-            $ENV{'remote_application_name'});
-        die SOAP::Fault->faultcode('Client')->faultstring('Not allowed')
-            ->faultdetail($reason_string);
-    }
-
-    my $user_entry = $list->get_list_member($email);
-    unless ((defined $user_entry)) {
-        $log->syslog('info', 'DEL %s %s from %s refused, not on list',
-            $listname, $email, $sender);
-        die SOAP::Fault->faultcode('Client')->faultstring('Not subscribed')
-            ->faultdetail('Not member of list or not subscribed');
-    }
-
-    # If a list is not 'open' and allow_subscribe_if_pending has been set
-    # to 'off' returns error report.
-    unless ($list->{'admin'}{'status'} eq 'open'
-        or Conf::get_robot_conf($robot, 'allow_subscribe_if_pending') eq 'on')
-    {
-        my $error =
-            sprintf 'Service unavailable because list status is \'%s\'',
-            $list->{'admin'}{'status'};
-        $log->syslog('info', 'List %s not open', $list);
-        die SOAP::Fault::faultcode("Server")->faultstring('List not open')
-            ->faultdetail($error);
-    }
-
-    # Really delete and rewrite to disk.
-    unless (
-        $list->delete_list_member(
-            'users'     => [$email],
-            'exclude'   => '1',
-            'operation' => 'del'
-        )
-        ) {
-        my $error =
-            "Unable to delete user $email from list $listname for command 'del'";
-        $log->syslog('info', 'DEL %s %s from %s failed, ' . $error);
-        die SOAP::Fault->faultcode('Server')
-            ->faultstring('Unable to remove subscriber information')
-            ->faultdetail('Database access failed');
-    }
-
-    ## Send a notice to the removed user, unless the owner indicated
-    ## quiet del.
-    unless ($quiet || $action =~ /quiet/i) {
-        unless (
-            Sympa::send_file(
-                $list, 'removed',
-                $email, {'auto_submitted' => 'auto-generated'}
-            )
-            ) {
-            $log->syslog('notice', 'Unable to send template "removed" to %s',
-                $email);
+    foreach my $report (@{$spindle->{stash} || []}) {
+        my $reason_string = get_reason_string($report, $robot);
+        if ($report->[1] eq 'auth') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
+                ->faultdetail($reason_string);
+        } elsif ($report->[1] eq 'intern') {
+            die SOAP::Fault->faultcode('Server')
+                ->faultstring('Internal error');
+        } elsif ($report->[1] eq 'notice') {
+            return SOAP::Data->name('result')->type('boolean')->value(1);
+        } elsif ($report->[1] eq 'user') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Undef')
+                ->faultdetail($reason_string);
         }
     }
-
-    $log->syslog('info', 'DEL %s %s from %s accepted (%d subscribers)',
-        $listname, $email, $sender, $list->get_total());
-    if ($action =~ /notify/i) {
-        $list->send_notify_to_owner(
-            'notice',
-            {   'who'     => $email,
-                'gecos'   => "",
-                'command' => 'del',
-                'by'      => $sender
-            }
-        );
-    }
-    return 1;
+    return SOAP::Data->name('result')->type('boolean')->value(1);
 }
 
 sub review {
@@ -1141,7 +996,8 @@ sub review {
         unless (defined $action);
 
     if ($action =~ /reject/i) {
-        my $reason_string = get_reason_string($result->{'reason'}, $robot);
+        my $reason_string = get_reason_string(
+            [{action => 'review'}, 'auth', $result->{'reason'}], $robot);
         $log->syslog('info', 'Review %s from %s refused (not allowed)',
             $listname, $sender);
         die SOAP::Fault->faultcode('Server')->faultstring('Not allowed')
@@ -1285,28 +1141,23 @@ sub fullReview {
 }
 
 sub signoff {
+    $log->syslog('notice', '(%s, %s)', @_);
     my ($class, $listname) = @_;
 
     my $sender = $ENV{'USER_EMAIL'};
     my $robot  = $ENV{'SYMPA_ROBOT'};
 
-    $log->syslog('notice', '(%s, %s)', $listname, $sender);
-
     unless ($sender) {
         die SOAP::Fault->faultcode('Client')
             ->faultstring('User not authenticated')
             ->faultdetail('You should login first');
     }
-
     unless ($listname) {
         die SOAP::Fault->faultcode('Client')
             ->faultstring('Incorrect number of parameters.')
             ->faultdetail('Use : <list> ');
     }
-
     my $list = Sympa::List->new($listname, $robot);
-
-    ## Is this list defined
     unless ($list) {
         $log->syslog('info', 'Sign off from %s for %s refused, list unknown',
             $listname, $sender);
@@ -1314,139 +1165,56 @@ sub signoff {
             ->faultdetail("List $listname unknown");
     }
 
-    if ($listname eq '*') {
-        my $success;
-        foreach my $list (Sympa::List::get_which($sender, $robot, 'member')) {
-            my $l = $list->{'name'};
-
-            $success ||= signoff($l, $sender);
-        }
-        return SOAP::Data->name('result')->value($success);
-    }
-
-    $list = Sympa::List->new($listname, $robot);
-
-    my $result = Sympa::Scenario::request_action(
-        $list,
-        'unsubscribe',
-        'md5',
-        {   'email'                   => $sender,
-            'sender'                  => $sender,
-            'remote_application_name' => $ENV{'remote_application_name'}
-        }
+    my $spindle = Sympa::Spindle::ProcessRequest->new(
+        context          => $list,
+        action           => 'signoff',
+        sender           => $sender,
+        email            => $sender,
+        md5_check        => 1,
+        scenario_context => {
+            sender                  => $sender,
+            remote_application_name => $ENV{remote_application_name},
+        },
     );
-    my $action;
-    $action = $result->{'action'} if (ref($result) eq 'HASH');
-
-    die SOAP::Fault->faultcode('Server')->faultstring('No action available.')
-        unless (defined $action);
-
-    if ($action =~ /reject/i) {
-        my $reason_string = get_reason_string($result->{'reason'}, $robot);
-        $log->syslog(
-            'info',
-            'Sign off from %s for the email %s of the user %s refused (not allowed)',
-            $listname,
-            $sender,
-            $sender
-        );
-        die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
-            ->faultdetail($reason_string);
+    unless ($spindle and $spindle->spin) {
+        die SOAP::Fault->faultcode('Server')->faultstring('Internal error');
     }
-    if ($action =~ /do_it/i) {
-        ## Now check if we know this email on the list and
-        ## remove it if found, otherwise just reject the
-        ## command.
-        unless ($list->is_list_member($sender)) {
-            $log->syslog('info', 'Sign off %s from %s refused, not on list',
-                $listname, $sender);
 
-            ## Tell the owner somebody tried to unsubscribe
-            if ($action =~ /notify/i) {
-                $list->send_notify_to_owner('warn-signoff',
-                    {'who' => $sender});
-            }
+    foreach my $report (@{$spindle->{stash} || []}) {
+        my $reason_string = get_reason_string($report, $robot);
+        if ($report->[1] eq 'auth') {
             die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
-                ->faultdetail(
-                "Email address $sender has not been found on the list $list->{'name'}. You did perhaps subscribe using a different address ?"
-                );
+                ->faultdetail($reason_string);
+        } elsif ($report->[1] eq 'intern') {
+            die SOAP::Fault->faultcode('Server')
+                ->faultstring('Internal error');
+        } elsif ($report->[1] eq 'notice') {
+            return SOAP::Data->name('result')->type('boolean')->value(1);
+        } elsif ($report->[1] eq 'user') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Undef')
+                ->faultdetail($reason_string);
         }
-
-        # If a list is not 'open' and allow_subscribe_if_pending has been set
-        # to 'off' returns error report.
-        unless ($list->{'admin'}{'status'} eq 'open'
-            or Conf::get_robot_conf($robot, 'allow_subscribe_if_pending') eq
-            'on') {
-            my $error =
-                sprintf 'Service unavailable because list status is \'%s\'',
-                $list->{'admin'}{'status'};
-            $log->syslog('info', 'List %s not open', $list);
-            die SOAP::Fault::faultcode("Server")
-                ->faultstring('List not open')->faultdetail($error);
-        }
-
-        ## Really delete and rewrite to disk.
-        $list->delete_list_member(
-            'users'     => [$sender],
-            'exclude'   => '1',
-            'operation' => 'signoff'
-        );
-
-        ## Notify the owner
-        if ($action =~ /notify/i) {
-            $list->send_notify_to_owner(
-                'notice',
-                {   'who'     => $sender,
-                    'command' => 'signoff'
-                }
-            );
-        }
-
-        ## Send bye.tpl to sender
-        unless (Sympa::send_file($list, 'bye', $sender, {})) {
-            $log->syslog('err', 'Unable to send template "bye" to %s',
-                $sender);
-        }
-
-        $log->syslog('info', 'Sign off %s from %s accepted',
-            $listname, $sender);
-
-        return SOAP::Data->name('result')->type('boolean')->value(1);
     }
-
-    $log->syslog('info',
-        'Sign off %s from %s aborted, unknown requested action in scenario',
-        $listname, $sender);
-    die SOAP::Fault->faultcode('Server')->faultstring('Undef')->faultdetail(
-        "Sign off %s from %s aborted because unknown requested action in scenario",
-        $listname, $sender
-    );
+    return SOAP::Data->name('result')->type('boolean')->value(1);
 }
 
 sub subscribe {
+    $log->syslog('notice', '(%s, %s, %s)', @_);
     my ($class, $listname, $gecos) = @_;
 
     my $sender = $ENV{'USER_EMAIL'};
     my $robot  = $ENV{'SYMPA_ROBOT'};
 
-    $log->syslog('info', '(%s, %s, %s)', $listname, $sender, $gecos);
-
     unless ($sender) {
         die SOAP::Fault->faultcode('Client')
             ->faultstring('User not authenticated')
             ->faultdetail('You should login first');
     }
-
     unless ($listname) {
         die SOAP::Fault->faultcode('Client')
             ->faultstring('Incorrect number of parameters')
             ->faultdetail('Use : <list> [user gecos]');
     }
-
-    $log->syslog('notice', '(%s, %s)', $listname, $sender);
-
-    ## Load the list if not already done, and reject the
-    ## subscription if this list is unknown to us.
     my $list = Sympa::List->new($listname, $robot);
     unless ($list) {
         $log->syslog('info',
@@ -1456,182 +1224,38 @@ sub subscribe {
             ->faultdetail("List $listname unknown");
     }
 
-    ## This is a really minimalistic handling of the comments,
-    ## it is far away from RFC-822 completeness.
-    $gecos =~ s/"/\\"/g;
-    $gecos = "\"$gecos\"" if ($gecos =~ /[<>\(\)]/);
-
-    ## query what to do with this subscribtion request
-    my $result = Sympa::Scenario::request_action(
-        $list,
-        'subscribe',
-        'md5',
-        {   'sender'                  => $sender,
-            'remote_application_name' => $ENV{'remote_application_name'}
-        }
+    my $spindle = Sympa::Spindle::ProcessRequest->new(
+        context          => $list,
+        action           => 'subscribe',
+        sender           => $sender,
+        email            => $sender,
+        gecos            => $gecos,
+        md5_check        => 1,
+        scenario_context => {
+            sender                  => $sender,
+            remote_application_name => $ENV{remote_application_name},
+        },
     );
-    my $action;
-    $action = $result->{'action'} if (ref($result) eq 'HASH');
-
-    die SOAP::Fault->faultcode('Server')->faultstring('No action available.')
-        unless (defined $action);
-
-    $log->syslog('debug2', 'SOAP subscribe action: %s', $action);
-
-    if ($action =~ /reject/i) {
-        my $reason_string = get_reason_string($result->{'reason'}, $robot);
-        $log->syslog('info',
-            'SOAP subscribe to %s from %s refused (not allowed)',
-            $listname, $sender);
-        die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
-            ->faultdetail($reason_string);
+    unless ($spindle and $spindle->spin) {
+        die SOAP::Fault->faultcode('Server')->faultstring('Internal error');
     }
-    if ($action =~ /owner/i) {
-        my $spool_req = Sympa::Spool::Auth->new;
-        my $request   = Sympa::Request->new(
-            context => $list,
-            action  => 'add',
-            email   => $sender,
-            gecos   => $gecos,
-            sender  => $sender,
-        );
-        my $keyauth = $spool_req->store($request);
 
-        $list->send_notify_to_owner(
-            'subrequest',
-            {   'who'     => $sender,
-                'keyauth' => $keyauth,
-                'replyto' => Sympa::get_address($robot),
-                'gecos'   => $gecos
-            }
-        );
-
-        $log->syslog('info', '%s from %s forwarded to the owners of the list',
-            $listname, $sender);
-        return SOAP::Data->name('result')->type('boolean')->value(1);
-    }
-    if ($action =~ /request_auth/i) {
-        my $request = Sympa::Request->new(
-            context => $list,
-            action  => 'subscribe',
-            email   => $sender,
-            gecos   => $gecos,
-            sender  => $sender,
-        );
-        my $spool_req = Sympa::Spool::Auth->new;
-        my $keyauth;
-        unless ($keyauth = $spool_req->store($request)) {
-            #XXX FIXME: Check if failed!
-        }
-
-        # Send notice to the user.
-        my $cmd_line = $request->cmd_line(canonic => 1);
-        unless (
-            Sympa::send_file(
-                $list,
-                'request_auth',
-                $sender,
-                {   cmd => $cmd_line,
-                    # Compat. <= 6.2.14.
-                    command => sprintf('AUTH %s %s', $keyauth, $cmd_line),
-                    keyauth => $keyauth,
-                    type    => $request->{action},
-                    to      => $sender,
-                    auto_submitted => 'auto-replied',
-                }
-            )
-            ) {
-            #XXX FIXME: Check if failed!
-        }
-
-        $log->syslog('info', '%s from %s, auth requested', $listname,
-            $sender);
-        return SOAP::Data->name('result')->type('boolean')->value(1);
-    }
-    if ($action =~ /do_it/i) {
-
-        my $is_sub = $list->is_list_member($sender);
-
-        unless (defined($is_sub)) {
-            $log->syslog('err', 'User lookup failed');
+    foreach my $report (@{$spindle->{stash} || []}) {
+        my $reason_string = get_reason_string($report, $robot);
+        if ($report->[1] eq 'auth') {
+            die SOAP::Fault->faultcode('Server')->faultstring('Not allowed.')
+                ->faultdetail($reason_string);
+        } elsif ($report->[1] eq 'intern') {
+            die SOAP::Fault->faultcode('Server')
+                ->faultstring('Internal error');
+        } elsif ($report->[1] eq 'notice') {
+            return SOAP::Data->name('result')->type('boolean')->value(1);
+        } elsif ($report->[1] eq 'user') {
             die SOAP::Fault->faultcode('Server')->faultstring('Undef')
-                ->faultdetail("SOAP subscribe : user lookup failed");
+                ->faultdetail($reason_string);
         }
-
-        if ($is_sub) {
-            # Only updates the date.  Options remain the same.
-            my %update = (update_date => time);
-            $update{gecos} = $gecos if defined $gecos and $gecos =~ /\S/;
-
-            unless ($list->update_list_member($sender, %update)) {
-                $log->syslog('err', 'User update failed');
-                die SOAP::Fault->faultcode('Server')->faultstring('Undef.')
-                    ->faultdetail("SOAP subscribe : update user failed");
-            }
-        } else {
-            # If a list is not 'open' and allow_subscribe_if_pending has been
-            # set to 'off' returns error report.
-            unless ($list->{'admin'}{'status'} eq 'open'
-                or
-                Conf::get_robot_conf($robot, 'allow_subscribe_if_pending') eq
-                'on') {
-                my $error =
-                    sprintf
-                    'Service unavailable because list status is \'%s\'',
-                    $list->{'admin'}{'status'};
-                $log->syslog('info', 'List %s not open', $list);
-                die SOAP::Fault::faultcode("Server")
-                    ->faultstring('List not open')->faultdetail($error);
-            }
-
-            my $u;
-            my $defaults = $list->get_default_user_options();
-            %{$u} = %{$defaults};
-            $u->{'email'} = $sender;
-            $u->{'gecos'} = $gecos;
-            $u->{'date'}  = $u->{'update_date'} = time;
-
-            die SOAP::Fault->faultcode('Server')->faultstring('Undef')
-                ->faultdetail("SOAP subscribe : add user failed")
-                unless $list->add_list_member($u);
-        }
-
-        my $u = Sympa::User->new($sender);
-        unless ($u->lang) {
-            $u->lang($list->{'admin'}{'lang'});
-            $u->save();
-        }
-
-        ## Now send the welcome file to the user
-        unless ($action =~ /quiet/i) {
-            unless ($list->send_probe_to_user('welcome', $sender)) {
-                $log->syslog('err', 'Unable to send template "bye" to %s',
-                    $sender);
-            }
-        }
-
-        ## If requested send notification to owners
-        if ($action =~ /notify/i) {
-            $list->send_notify_to_owner(
-                'notice',
-                {   'who'     => $sender,
-                    'gecos'   => $gecos,
-                    'command' => 'subscribe'
-                }
-            );
-        }
-        $log->syslog('info', '%s from %s accepted', $listname, $sender);
-
-        return SOAP::Data->name('result')->type('boolean')->value(1);
     }
-
-    $log->syslog('info',
-        '%s from %s aborted, unknown requested action in scenario',
-        $listname, $sender);
-    die SOAP::Fault->faultcode('Server')->faultstring('Undef')->faultdetail(
-        "SOAP subscribe : %s from %s aborted because unknown requested action in scenario",
-        $listname, $sender
-    );
+    return SOAP::Data->name('result')->type('boolean')->value(1);
 }
 
 ## Which list the user is subscribed to
@@ -1973,14 +1597,22 @@ sub struct_to_soap {
 }
 
 sub get_reason_string {
-    my ($reason, $robot) = @_;
+    my $report = shift;
+    my $robot  = shift;
 
-    my $data = {'reason' => $reason};
+    my $data = {
+        report_type  => $report->[1],
+        report_entry => $report->[2],
+        report_param => {
+            action => $report->[0]->{action},
+            %{$report->[3] || {}},
+        },
+    };
     my $string;
 
     my $template =
         Sympa::Template->new($robot, subdir => 'mail_tt2');    # FIXME: lang?
-    unless ($template->parse($data, 'authorization_reject.tt2', \$string)) {
+    unless ($template->parse($data, 'report.tt2', \$string)) {
         my $error = $template->{last_error};
         $error = $error->as_string if ref $error;
         Sympa::send_notify_to_listmaster($robot, 'web_tt2_error', [$error]);
