@@ -8,6 +8,9 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+# directory of this distribution and at
+# <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1368,12 +1371,18 @@ sub upgrade {
                 next;
             }
 
-            my $spool_digest = Sympa::Spool::Digest->new(%$metadata);
-            next unless $spool_digest;
-
             rename $Conf::Conf{'queuedigest'} . '/' . $filename,
                 $Conf::Conf{'queuedigest'} . '/' . $filename . '_migrated';
 
+            my $spool_digest = Sympa::Spool::Digest->new(%$metadata);
+            unless ($spool_digest) {
+                rename $Conf::Conf{'queuedigest'} . '/'
+                    . $filename
+                    . '_migrated',
+                    $Conf::Conf{'queuedigest'} . '/' . $filename;
+                next;
+            }
+
             local $RS = "\n\n" . $digest_separator . "\n\n";
             open my $fh, '<',
                 $Conf::Conf{'queuedigest'} . '/' . $filename . '_migrated'
